@@ -4,40 +4,40 @@
 #'   values for the Region Of Practical Equivalence (ROPE).
 #'
 #' @details \cite{Kruschke (2018)} suggests that the region of practical
-#'   equivalence could be set, by default, to a range from \code{-0.1} to
-#'   \code{0.1} of a standardized parameter (negligible effect size
+#'   equivalence could be set, by default, to a range from `-0.1` to
+#'   `0.1` of a standardized parameter (negligible effect size
 #'   according to Cohen, 1988).
 #'
 #'   \itemize{
-#'     \item For \strong{linear models (lm)}, this can be generalised to
+#'     \item For **linear models (lm)**, this can be generalised to
 #'     \ifelse{html}{\out{-0.1 * SD<sub>y</sub>, 0.1 *
 #'     SD<sub>y</sub>}}{\eqn{[-0.1*SD_{y}, 0.1*SD_{y}]}}.
 #'
-#'     \item For \strong{logistic models}, the parameters expressed in log odds
+#'     \item For **logistic models**, the parameters expressed in log odds
 #'     ratio can be converted to standardized difference through the formula
 #'     \ifelse{html}{\out{&pi;/&radic;(3)}}{\eqn{\pi/\sqrt{3}}}, resulting in a
-#'     range of \code{-0.18} to \code{0.18}.
+#'     range of `-0.18` to `0.18`.
 #'
-#'     \item For other models with \strong{binary outcome}, it is strongly
+#'     \item For other models with **binary outcome**, it is strongly
 #'     recommended to manually specify the rope argument. Currently, the same
 #'     default is applied that for logistic models.
 #'
-#'     \item For models from \strong{count data}, the residual variance is used.
+#'     \item For models from **count data**, the residual variance is used.
 #'     This is a rather experimental threshold and is probably often similar to
-#'     \code{-0.1, 0.1}, but should be used with care!
+#'     `-0.1, 0.1`, but should be used with care!
 #'
-#'     \item For \strong{t-tests}, the standard deviation of the response is
+#'     \item For **t-tests**, the standard deviation of the response is
 #'     used, similarly to linear models (see above).
 #'
-#'     \item For \strong{correlations}, \code{-0.05, 0.05} is used, i.e., half
+#'     \item For **correlations**, `-0.05, 0.05` is used, i.e., half
 #'     the value of a negligible correlation as suggested by Cohen's (1988)
 #'     rules of thumb.
 #'
-#'     \item For all other models, \code{-0.1, 0.1} is used to determine the
+#'     \item For all other models, `-0.1, 0.1` is used to determine the
 #'     ROPE limits, but it is strongly advised to specify it manually.
 #'   }
 #'
-#' @param x A \code{stanreg}, \code{brmsfit} or \code{BFBayesFactor} object.
+#' @param x A `stanreg`, `brmsfit` or `BFBayesFactor` object.
 #' @param verbose Toggle warnings.
 #' @inheritParams rope
 #'
@@ -85,17 +85,17 @@ rope_range <- function(x, ...) {
 #' @export
 rope_range.default <- function(x, verbose = TRUE, ...) {
   response <- insight::get_response(x)
+  response_transform <- insight::find_transformation(x)
   information <- insight::model_info(x)
 
   if (insight::is_multivariate(x)) {
-    ret <- mapply(function(i, j) .rope_range(x, i, j), information, response, verbose)
-
-    # return matrix as named list
-    # see https://stackoverflow.com/questions/6819804/how-to-convert-a-matrix-to-a-list-of-column-vectors-in-r
-    # this is not the fastest solution bot keeps columns names
-    as.list(as.data.frame(ret))
+    ret <- mapply(
+      function(i, j, ...) .rope_range(x, i, j), information, response, response_transform, verbose,
+      SIMPLIFY = FALSE
+    )
+    return(ret)
   } else {
-    .rope_range(x, information, response, verbose)
+    .rope_range(x, information, response, response_transform, verbose)
   }
 }
 
@@ -107,7 +107,7 @@ rope_range.mlm <- function(x, verbose = TRUE, ...) {
   response <- insight::get_response(x)
   information <- insight::model_info(x)
 
-  lapply(response, function(i) .rope_range(x, information, i, verbose))
+  lapply(response, function(i) .rope_range(x, information, i, response_transform = NULL, verbose))
 }
 
 
@@ -115,8 +115,7 @@ rope_range.mlm <- function(x, verbose = TRUE, ...) {
 # helper ------------------
 
 
-.rope_range <- function(x, information = NULL, response = NULL, verbose = TRUE) {
-
+.rope_range <- function(x, information = NULL, response = NULL, response_transform = NULL, verbose = TRUE) {
   # if(method != "legacy") {
   #   message("Other ROPE range methods than 'legacy' are currently not implemented. See https://github.com/easystats/bayestestR/issues/364", call. = FALSE)
   # }
@@ -124,15 +123,27 @@ rope_range.mlm <- function(x, verbose = TRUE, ...) {
 
   negligible_value <- tryCatch(
     {
-      if (!is.null(response) && information$link == "identity") {
+      if (!is.null(response_transform) && grepl("log", response_transform, fixed = TRUE)) {
+        # for log-transform, we assume that a 1% change represents the ROPE adequately
+        # see https://github.com/easystats/bayestestR/issues/487
+        0.01
+      } else if (information$is_linear && information$link_function == "log") {
+        # for log-transform, we assume that a 1% change represents the ROPE adequately
+        # see https://github.com/easystats/bayestestR/issues/487
+        0.01
+      } else if (information$family == "lognormal") {
+        # for log-transform, we assume that a 1% change represents the ROPE adequately
+        # see https://github.com/easystats/bayestestR/issues/487
+        0.01
+      } else if (!is.null(response) && information$link_function == "identity") {
         # Linear Models
         0.1 * stats::sd(response, na.rm = TRUE)
         # 0.1 * stats::sigma(x) # https://github.com/easystats/bayestestR/issues/364
-      } else if (information$link == "logit") {
+      } else if (information$is_logit) {
         # Logistic Models (any)
         # Sigma==pi / sqrt(3)
         0.1 * pi / sqrt(3)
-      } else if (information$link == "probit") {
+      } else if (information$is_probit) {
         # Probit models
         # Sigma==1
         0.1 * 1
