@@ -78,7 +78,8 @@
   }
 
 
-  if (!inherits(prior, "emmGrid")) { # then is it a model
+  if (!inherits(prior, "emmGrid")) {
+    # then is it a model
     on.exit(
       stop(
         "Unable to reconstruct prior estimates.\n",
@@ -141,7 +142,8 @@
     )
   }
 
-  if (!inherits(prior, "emm_list")) { # prior is a model
+  if (!inherits(prior, "emm_list")) {
+    # prior is a model
 
     if (inherits(prior, "brmsfit")) {
       stop("Cannot rebuild prior emm_list from a brmsfit model.", call. = FALSE)
@@ -223,8 +225,8 @@
     for (m in seq_len(nrow(df.model))) {
       tmp_terms <- .make_terms(df.model$Modelnames[m])
       if (length(tmp_terms) > 0) {
-        missing_terms <- !tmp_terms %in% colnames(df.model) # For R < 3.6.0
-        if (any(missing_terms)) df.model[, tmp_terms[missing_terms]] <- NA # For R < 3.6.0
+        missing_terms <- !tmp_terms %in% colnames(df.model)
+        if (any(missing_terms)) df.model[, tmp_terms[missing_terms]] <- NA
         df.model[m, tmp_terms] <- TRUE
       }
     }
@@ -410,10 +412,9 @@ as.double.bayesfactor_restricted <- as.numeric.bayesfactor_inclusion
 .logspline <- function(x, ...) {
   insight::check_if_installed("logspline")
 
-  # arg_names <- names(formals(logspline::logspline, envir = parent.frame()))
-  arg_names <- names(formals(logspline::logspline)) # support R<3.6.0
   in_args <- list(...)
-
+  # arg_names <- names(formals(logspline::logspline, envir = parent.frame()))
+  arg_names <- names(formals(logspline::logspline))
   in_args <- in_args[names(in_args) %in% arg_names]
   in_args <- c(list(x = x), in_args)
   suppressWarnings(do.call(logspline::logspline, in_args))
