@@ -1,5 +1,7 @@
 #' @keywords internal
-.check_multicollinearity <- function(model, method = "equivalence_test", threshold = 0.7, ...) {
+.check_multicollinearity <- function(model,
+                                     method = "equivalence_test",
+                                     threshold = 0.7, ...) {
   valid_parameters <- insight::find_parameters(model, parameters = "^(?!(r_|sd_|prior_|cor_|lp__|b\\[))", flatten = TRUE)
 
   if (inherits(model, "stanfit")) {
@@ -27,7 +29,6 @@
       results <- results[results$pvalue < 0.05 & results$Var1 != results$Var2, ]
 
       if (nrow(results) > 0) {
-
         # Remove duplicates
         results$where <- paste0(results$Var1, " and ", results$Var2)
         results$where2 <- paste0(results$Var2, " and ", results$Var1)
