@@ -1,5 +1,4 @@
-if (require("rstanarm") && suppressPackageStartupMessages(require("bayestestR", quietly = TRUE)) &&
-  require("testthat") && require("emmeans")) {
+if (suppressPackageStartupMessages(require("bayestestR", quietly = TRUE)) && require("testthat")) {
   test_that("si.numeric", {
     set.seed(333)
     prior <- distribution_normal(1000, mean = 0, sd = 1)
@@ -26,10 +25,11 @@ if (require("rstanarm") && suppressPackageStartupMessages(require("bayestestR",
 
   test_that("si.rstanarm", {
     skip_on_cran()
+    skip_if_not_installed("rstanarm")
 
     data(sleep)
-    contrasts(sleep$group) <- contr.orthonorm # See vignette
-    stan_model <- stan_lmer(extra ~ group + (1 | ID), data = sleep, refresh = 0)
+    contrasts(sleep$group) <- contr.equalprior_pairs # See vignette
+    stan_model <- rstanarm::stan_glmer(extra ~ group + (1 | ID), data = sleep, refresh = 0)
 
     set.seed(333)
     stan_model_p <- update(stan_model, prior_PD = TRUE)
@@ -41,8 +41,9 @@ if (require("rstanarm") && suppressPackageStartupMessages(require("bayestestR",
     expect_s3_class(res1, c("bayestestR_si"))
     expect_equal(res1, res2)
 
+    skip_if_not_installed("emmeans")
     set.seed(123)
-    group_diff <- pairs(emmeans(stan_model, ~group))
+    group_diff <- pairs(emmeans::emmeans(stan_model, ~group))
     res3 <- si(group_diff, prior = stan_model, verbose = FALSE)
 
     expect_equal(res3$CI_low, -2.746, tolerance = 0.3)
